You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@struts.apache.org by lu...@apache.org on 2011/11/30 20:35:48 UTC

svn commit: r1208724 - in /struts/struts2/branches/STRUTS_3_X: apps/showcase/src/main/java/org/apache/struts2/showcase/action/ apps/showcase/src/main/java/org/apache/struts2/showcase/actionchaining/ apps/showcase/src/main/java/org/apache/struts2/showca...

Author: lukaszlenart
Date: Wed Nov 30 19:35:34 2011
New Revision: 1208724

URL: http://svn.apache.org/viewvc?rev=1208724&view=rev
Log:
WW-3714 renames org.opensymphony.xwork2 to org.apache.struts2.xwork2 - part 1

Added:
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/
      - copied from r1207009, struts/struts2/trunk/xwork-core/src/main/java/com/opensymphony/xwork2/
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/
      - copied from r1207009, struts/struts2/trunk/xwork-core/src/test/java/com/opensymphony/xwork2/
Removed:
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/Action.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ActionChainResult.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ActionContext.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ActionEventListener.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ActionInvocation.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ActionProxy.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ActionProxyFactory.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ActionSupport.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/ActionConfig.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/impl/AbstractMatcher.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/impl/ActionConfigMatcher.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/AbstractInterceptor.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/accessor/
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/spring/interceptor/ActionAutowiringInterceptor.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/AbstractFieldValidatorDescription.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/AbstractRangeValidator.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/com/opensymphony/xwork2/ActionContextTest.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/com/opensymphony/xwork2/ActionContextThreadLocalTest.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/com/opensymphony/xwork2/ActionInvocationTest.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/com/opensymphony/xwork2/ActionNestingTest.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/com/opensymphony/xwork2/config/entities/ActionConfigTest.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/com/opensymphony/xwork2/config/impl/ActionConfigMatcherTest.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/com/opensymphony/xwork2/ognl/accessor/
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/com/opensymphony/xwork2/spring/ActionsFromSpringTest.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/com/opensymphony/xwork2/spring/interceptor/ActionAutowiringInterceptorTest.java
Modified:
    struts/struts2/branches/STRUTS_3_X/apps/showcase/src/main/java/org/apache/struts2/showcase/action/AbstractCRUDAction.java
    struts/struts2/branches/STRUTS_3_X/apps/showcase/src/main/java/org/apache/struts2/showcase/actionchaining/ActionChain1.java
    struts/struts2/branches/STRUTS_3_X/apps/showcase/src/main/java/org/apache/struts2/showcase/actionchaining/ActionChain2.java
    struts/struts2/branches/STRUTS_3_X/apps/showcase/src/main/java/org/apache/struts2/showcase/actionchaining/ActionChain3.java
    struts/struts2/branches/STRUTS_3_X/apps/showcase/src/main/java/org/apache/struts2/showcase/validation/AbstractValidationActionSupport.java
    struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/ActionComponent.java
    struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/ActionError.java
    struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/ActionMessage.java
    struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ActionContextCleanUp.java
    struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/ActionMapper.java
    struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/ActionMapping.java
    struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/ActionMappingParametersInteceptor.java
    struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ActionErrorModel.java
    struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ActionMessageModel.java
    struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ActionModel.java
    struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/jsp/ui/ActionErrorTag.java
    struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/jsp/ui/ActionMessageTag.java
    struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/velocity/components/AbstractDirective.java
    struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/velocity/components/ActionDirective.java
    struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/velocity/components/ActionErrorDirective.java
    struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/velocity/components/ActionMessageDirective.java
    struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/xslt/AbstractAdapterNode.java
    struts/struts2/branches/STRUTS_3_X/core/src/test/java/org/apache/struts2/components/ActionComponentTest.java
    struts/struts2/branches/STRUTS_3_X/core/src/test/java/org/apache/struts2/views/jsp/AbstractTagTest.java
    struts/struts2/branches/STRUTS_3_X/core/src/test/java/org/apache/struts2/views/jsp/AbstractUITagTest.java
    struts/struts2/branches/STRUTS_3_X/core/src/test/java/org/apache/struts2/views/jsp/ui/ActionErrorTagTest.java
    struts/struts2/branches/STRUTS_3_X/core/src/test/java/org/apache/struts2/views/jsp/ui/ActionMessageTagTest.java
    struts/struts2/branches/STRUTS_3_X/plugins/codebehind/src/test/java/org/apache/struts2/config/cltest/ActionImpl.java
    struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ActionNamesAction.java
    struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/AbstractRemoteBean.java
    struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/AbstractValidateBean.java
    struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/test/java/org/apache/struts2/dojo/views/jsp/ui/AbstractTagTest.java
    struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/test/java/org/apache/struts2/dojo/views/jsp/ui/AbstractUITagTest.java
    struts/struts2/branches/STRUTS_3_X/plugins/gxp/src/main/java/org/apache/struts2/views/gxp/AbstractGxp.java
    struts/struts2/branches/STRUTS_3_X/plugins/gxp/src/main/java/org/apache/struts2/views/gxp/AbstractGxpResult.java
    struts/struts2/branches/STRUTS_3_X/plugins/javatemplates/src/main/java/org/apache/struts2/views/java/simple/AbstractTagHandler.java
    struts/struts2/branches/STRUTS_3_X/plugins/javatemplates/src/test/java/org/apache/struts2/views/java/simple/AbstractTest.java
    struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/ActionFormResetInterceptor.java
    struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/ActionFormValidationInterceptor.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/Action.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionChainResult.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionContext.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionEventListener.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionInvocation.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionProxy.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionProxyFactory.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/config/entities/ActionConfig.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/config/impl/AbstractMatcher.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/config/impl/ActionConfigMatcher.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/interceptor/AbstractInterceptor.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/spring/interceptor/ActionAutowiringInterceptor.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/validator/metadata/AbstractFieldValidatorDescription.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/validator/validators/AbstractRangeValidator.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/ActionContextTest.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/ActionContextThreadLocalTest.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/ActionInvocationTest.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/ActionNestingTest.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/config/entities/ActionConfigTest.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/config/impl/ActionConfigMatcherTest.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/spring/ActionsFromSpringTest.java
    struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/spring/interceptor/ActionAutowiringInterceptorTest.java

Modified: struts/struts2/branches/STRUTS_3_X/apps/showcase/src/main/java/org/apache/struts2/showcase/action/AbstractCRUDAction.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/apps/showcase/src/main/java/org/apache/struts2/showcase/action/AbstractCRUDAction.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/apps/showcase/src/main/java/org/apache/struts2/showcase/action/AbstractCRUDAction.java (original)
+++ struts/struts2/branches/STRUTS_3_X/apps/showcase/src/main/java/org/apache/struts2/showcase/action/AbstractCRUDAction.java Wed Nov 30 19:35:34 2011
@@ -27,7 +27,7 @@ import org.apache.log4j.Logger;
 import org.apache.struts2.showcase.dao.Dao;
 import org.apache.struts2.showcase.model.IdEntity;
 
-import com.opensymphony.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.ActionSupport;
 
 /**
  * AbstractCRUDAction.

Modified: struts/struts2/branches/STRUTS_3_X/apps/showcase/src/main/java/org/apache/struts2/showcase/actionchaining/ActionChain1.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/apps/showcase/src/main/java/org/apache/struts2/showcase/actionchaining/ActionChain1.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/apps/showcase/src/main/java/org/apache/struts2/showcase/actionchaining/ActionChain1.java (original)
+++ struts/struts2/branches/STRUTS_3_X/apps/showcase/src/main/java/org/apache/struts2/showcase/actionchaining/ActionChain1.java Wed Nov 30 19:35:34 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.showcase.actionchaining;
 
-import com.opensymphony.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.ActionSupport;
 
 /**
  *

Modified: struts/struts2/branches/STRUTS_3_X/apps/showcase/src/main/java/org/apache/struts2/showcase/actionchaining/ActionChain2.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/apps/showcase/src/main/java/org/apache/struts2/showcase/actionchaining/ActionChain2.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/apps/showcase/src/main/java/org/apache/struts2/showcase/actionchaining/ActionChain2.java (original)
+++ struts/struts2/branches/STRUTS_3_X/apps/showcase/src/main/java/org/apache/struts2/showcase/actionchaining/ActionChain2.java Wed Nov 30 19:35:34 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.showcase.actionchaining;
 
-import com.opensymphony.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.ActionSupport;
 
 /**
  *

Modified: struts/struts2/branches/STRUTS_3_X/apps/showcase/src/main/java/org/apache/struts2/showcase/actionchaining/ActionChain3.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/apps/showcase/src/main/java/org/apache/struts2/showcase/actionchaining/ActionChain3.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/apps/showcase/src/main/java/org/apache/struts2/showcase/actionchaining/ActionChain3.java (original)
+++ struts/struts2/branches/STRUTS_3_X/apps/showcase/src/main/java/org/apache/struts2/showcase/actionchaining/ActionChain3.java Wed Nov 30 19:35:34 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.showcase.actionchaining;
 
-import com.opensymphony.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.ActionSupport;
 
 /**
  *

Modified: struts/struts2/branches/STRUTS_3_X/apps/showcase/src/main/java/org/apache/struts2/showcase/validation/AbstractValidationActionSupport.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/apps/showcase/src/main/java/org/apache/struts2/showcase/validation/AbstractValidationActionSupport.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/apps/showcase/src/main/java/org/apache/struts2/showcase/validation/AbstractValidationActionSupport.java (original)
+++ struts/struts2/branches/STRUTS_3_X/apps/showcase/src/main/java/org/apache/struts2/showcase/validation/AbstractValidationActionSupport.java Wed Nov 30 19:35:34 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.showcase.validation;
 
-import com.opensymphony.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.ActionSupport;
 
 /**
  */

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/ActionComponent.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/ActionComponent.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/ActionComponent.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/ActionComponent.java Wed Nov 30 19:35:34 2011
@@ -43,15 +43,15 @@ import org.apache.struts2.views.annotati
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 import org.apache.struts2.views.jsp.TagUtils;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionProxy;
-import com.opensymphony.xwork2.ActionProxyFactory;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.ValueStackFactory;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionProxy;
+import org.apache.struts2.xwork2.ActionProxyFactory;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStackFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/ActionError.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/ActionError.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/ActionError.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/ActionError.java Wed Nov 30 19:35:34 2011
@@ -21,7 +21,7 @@
 
 package org.apache.struts2.components;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 import org.apache.commons.lang.StringUtils;
 import org.apache.struts2.views.annotations.StrutsTag;
 import org.apache.struts2.views.annotations.StrutsTagAttribute;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/ActionMessage.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/ActionMessage.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/ActionMessage.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/ActionMessage.java Wed Nov 30 19:35:34 2011
@@ -21,7 +21,7 @@
 
 package org.apache.struts2.components;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 import org.apache.commons.lang.StringUtils;
 import org.apache.struts2.views.annotations.StrutsTag;
 import org.apache.struts2.views.annotations.StrutsTagAttribute;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ActionContextCleanUp.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ActionContextCleanUp.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ActionContextCleanUp.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ActionContextCleanUp.java Wed Nov 30 19:35:34 2011
@@ -32,10 +32,10 @@ import javax.servlet.ServletResponse;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.util.profiling.UtilTimerStack;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.profiling.UtilTimerStack;
 
 /**
  * <!-- SNIPPET START: description -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/ActionMapper.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/ActionMapper.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/ActionMapper.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/ActionMapper.java Wed Nov 30 19:35:34 2011
@@ -23,7 +23,7 @@ package org.apache.struts2.dispatcher.ma
 
 import javax.servlet.http.HttpServletRequest;
 
-import com.opensymphony.xwork2.config.ConfigurationManager;
+import org.apache.struts2.xwork2.config.ConfigurationManager;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/ActionMapping.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/ActionMapping.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/ActionMapping.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/ActionMapping.java Wed Nov 30 19:35:34 2011
@@ -23,7 +23,7 @@ package org.apache.struts2.dispatcher.ma
 
 import java.util.Map;
 
-import com.opensymphony.xwork2.Result;
+import org.apache.struts2.xwork2.Result;
 
 /**
  * Simple class that holds the action mapping information used to invoke a

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/ActionMappingParametersInteceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/ActionMappingParametersInteceptor.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ActionErrorModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ActionErrorModel.java Wed Nov 30 19:35:34 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.ActionError;
 import org.apache.struts2.components.Component;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see ActionError

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ActionMessageModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ActionMessageModel.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ActionMessageModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ActionMessageModel.java Wed Nov 30 19:35:34 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.ActionMessage;
 import org.apache.struts2.components.Component;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see ActionMessage

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ActionModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ActionModel.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ActionModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ActionModel.java Wed Nov 30 19:35:34 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.ActionComponent;
 import org.apache.struts2.components.Component;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see ActionComponent

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/jsp/ui/ActionErrorTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/jsp/ui/ActionErrorTag.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/jsp/ui/ActionErrorTag.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/jsp/ui/ActionErrorTag.java Wed Nov 30 19:35:34 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.ActionError;
 import org.apache.struts2.components.Component;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * ActionError Tag.

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/jsp/ui/ActionMessageTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/jsp/ui/ActionMessageTag.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/jsp/ui/ActionMessageTag.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/jsp/ui/ActionMessageTag.java Wed Nov 30 19:35:34 2011
@@ -26,9 +26,8 @@ import javax.servlet.http.HttpServletRes
 
 import org.apache.struts2.components.ActionMessage;
 import org.apache.struts2.components.Component;
-import org.apache.struts2.components.ActionError;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * ActionMessage Tag.

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/velocity/components/AbstractDirective.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/velocity/components/AbstractDirective.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/velocity/components/AbstractDirective.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/velocity/components/AbstractDirective.java Wed Nov 30 19:35:34 2011
@@ -38,9 +38,9 @@ import org.apache.velocity.exception.Res
 import org.apache.velocity.runtime.directive.Directive;
 import org.apache.velocity.runtime.parser.node.Node;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 public abstract class AbstractDirective extends Directive {
     public String getName() {

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/velocity/components/ActionDirective.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/velocity/components/ActionDirective.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/velocity/components/ActionDirective.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/velocity/components/ActionDirective.java Wed Nov 30 19:35:34 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.ActionComponent;
 import org.apache.struts2.components.Component;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see ActionComponent

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/velocity/components/ActionErrorDirective.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/velocity/components/ActionErrorDirective.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/velocity/components/ActionErrorDirective.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/velocity/components/ActionErrorDirective.java Wed Nov 30 19:35:34 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.ActionError;
 import org.apache.struts2.components.Component;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see ActionError

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/velocity/components/ActionMessageDirective.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/velocity/components/ActionMessageDirective.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/velocity/components/ActionMessageDirective.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/velocity/components/ActionMessageDirective.java Wed Nov 30 19:35:34 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.ActionMessage;
 import org.apache.struts2.components.Component;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see ActionMessage

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/xslt/AbstractAdapterNode.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/xslt/AbstractAdapterNode.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/xslt/AbstractAdapterNode.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/xslt/AbstractAdapterNode.java Wed Nov 30 19:35:34 2011
@@ -33,8 +33,8 @@ import org.w3c.dom.Node;
 import org.w3c.dom.NodeList;
 import org.w3c.dom.UserDataHandler;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * AbstractAdapterNode is the base for childAdapters that expose a read-only view

Modified: struts/struts2/branches/STRUTS_3_X/core/src/test/java/org/apache/struts2/components/ActionComponentTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/test/java/org/apache/struts2/components/ActionComponentTest.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/test/java/org/apache/struts2/components/ActionComponentTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/test/java/org/apache/struts2/components/ActionComponentTest.java Wed Nov 30 19:35:34 2011
@@ -29,7 +29,7 @@ import org.springframework.mock.web.Mock
 import org.springframework.mock.web.MockHttpServletResponse;
 
 import com.mockobjects.dynamic.Mock;
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 public class ActionComponentTest extends StrutsTestCase {
 

Modified: struts/struts2/branches/STRUTS_3_X/core/src/test/java/org/apache/struts2/views/jsp/AbstractTagTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/test/java/org/apache/struts2/views/jsp/AbstractTagTest.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/test/java/org/apache/struts2/views/jsp/AbstractTagTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/test/java/org/apache/struts2/views/jsp/AbstractTagTest.java Wed Nov 30 19:35:34 2011
@@ -38,11 +38,10 @@ import org.apache.struts2.dispatcher.Req
 import org.apache.struts2.dispatcher.SessionMap;
 
 import com.mockobjects.dynamic.Mock;
-import com.opensymphony.xwork2.Action;
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.ValueStackFactory;
+import org.apache.struts2.xwork2.Action;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/core/src/test/java/org/apache/struts2/views/jsp/AbstractUITagTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/test/java/org/apache/struts2/views/jsp/AbstractUITagTest.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/test/java/org/apache/struts2/views/jsp/AbstractUITagTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/test/java/org/apache/struts2/views/jsp/AbstractUITagTest.java Wed Nov 30 19:35:34 2011
@@ -21,9 +21,9 @@
 
 package org.apache.struts2.views.jsp;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.commons.beanutils.BeanUtils;
 import org.apache.struts2.ServletActionContext;
 import org.apache.struts2.views.jsp.ui.AbstractUITag;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/test/java/org/apache/struts2/views/jsp/ui/ActionErrorTagTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/test/java/org/apache/struts2/views/jsp/ui/ActionErrorTagTest.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/test/java/org/apache/struts2/views/jsp/ui/ActionErrorTagTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/test/java/org/apache/struts2/views/jsp/ui/ActionErrorTagTest.java Wed Nov 30 19:35:34 2011
@@ -21,8 +21,8 @@
 
 package org.apache.struts2.views.jsp.ui;
 
-import com.opensymphony.xwork2.Action;
-import com.opensymphony.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.Action;
+import org.apache.struts2.xwork2.ActionSupport;
 import org.apache.commons.lang.StringUtils;
 import org.apache.struts2.TestAction;
 import org.apache.struts2.views.jsp.AbstractUITagTest;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/test/java/org/apache/struts2/views/jsp/ui/ActionMessageTagTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/test/java/org/apache/struts2/views/jsp/ui/ActionMessageTagTest.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/test/java/org/apache/struts2/views/jsp/ui/ActionMessageTagTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/test/java/org/apache/struts2/views/jsp/ui/ActionMessageTagTest.java Wed Nov 30 19:35:34 2011
@@ -21,8 +21,8 @@
 
 package org.apache.struts2.views.jsp.ui;
 
-import com.opensymphony.xwork2.Action;
-import com.opensymphony.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.Action;
+import org.apache.struts2.xwork2.ActionSupport;
 import org.apache.commons.lang.StringUtils;
 import org.apache.struts2.TestAction;
 import org.apache.struts2.views.jsp.AbstractUITagTest;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/codebehind/src/test/java/org/apache/struts2/config/cltest/ActionImpl.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/codebehind/src/test/java/org/apache/struts2/config/cltest/ActionImpl.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/codebehind/src/test/java/org/apache/struts2/config/cltest/ActionImpl.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/codebehind/src/test/java/org/apache/struts2/config/cltest/ActionImpl.java Wed Nov 30 19:35:34 2011
@@ -21,7 +21,7 @@
 
 package org.apache.struts2.config.cltest;
 
-import com.opensymphony.xwork2.Action;
+import org.apache.struts2.xwork2.Action;
 
 public class ActionImpl implements Action {
 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ActionNamesAction.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ActionNamesAction.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ActionNamesAction.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ActionNamesAction.java Wed Nov 30 19:35:34 2011
@@ -21,9 +21,9 @@
 
 package org.apache.struts2.config_browser;
 
-import com.opensymphony.xwork2.ActionSupport;
-import com.opensymphony.xwork2.config.entities.ActionConfig;
-import com.opensymphony.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.config.entities.ActionConfig;
+import org.apache.struts2.xwork2.inject.Inject;
 import org.apache.struts2.StrutsConstants;
 
 import java.util.Set;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/AbstractRemoteBean.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/AbstractRemoteBean.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/AbstractRemoteBean.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/AbstractRemoteBean.java Wed Nov 30 19:35:34 2011
@@ -30,7 +30,7 @@ import org.apache.struts2.components.Clo
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 import org.apache.struts2.views.annotations.StrutsTagSkipInheritance;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * AbstractRemoteCallUIBean is superclass for all components dealing with remote

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/AbstractValidateBean.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/AbstractValidateBean.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/AbstractValidateBean.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/AbstractValidateBean.java Wed Nov 30 19:35:34 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Form;
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * Base class for tags that perform AJAX validation

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/test/java/org/apache/struts2/dojo/views/jsp/ui/AbstractTagTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/test/java/org/apache/struts2/dojo/views/jsp/ui/AbstractTagTest.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/test/java/org/apache/struts2/dojo/views/jsp/ui/AbstractTagTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/test/java/org/apache/struts2/dojo/views/jsp/ui/AbstractTagTest.java Wed Nov 30 19:35:34 2011
@@ -39,10 +39,10 @@ import org.apache.struts2.dojo.TestActio
 import org.apache.struts2.dojo.components.Head;
 
 import com.mockobjects.dynamic.Mock;
-import com.opensymphony.xwork2.Action;
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.Action;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/test/java/org/apache/struts2/dojo/views/jsp/ui/AbstractUITagTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/test/java/org/apache/struts2/dojo/views/jsp/ui/AbstractUITagTest.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/test/java/org/apache/struts2/dojo/views/jsp/ui/AbstractUITagTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/test/java/org/apache/struts2/dojo/views/jsp/ui/AbstractUITagTest.java Wed Nov 30 19:35:34 2011
@@ -38,9 +38,9 @@ import java.util.StringTokenizer;
 import org.apache.struts2.ServletActionContext;
 import org.apache.struts2.views.jsp.ui.AbstractUITag;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  */

Modified: struts/struts2/branches/STRUTS_3_X/plugins/gxp/src/main/java/org/apache/struts2/views/gxp/AbstractGxp.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/gxp/src/main/java/org/apache/struts2/views/gxp/AbstractGxp.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/gxp/src/main/java/org/apache/struts2/views/gxp/AbstractGxp.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/gxp/src/main/java/org/apache/struts2/views/gxp/AbstractGxp.java Wed Nov 30 19:35:34 2011
@@ -23,10 +23,10 @@ package org.apache.struts2.views.gxp;
 import com.google.common.annotations.VisibleForTesting;
 import com.google.gxp.base.GxpContext;
 import com.google.gxp.base.MarkupClosure;
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.ValueStackFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStackFactory;
 
 import java.io.PrintWriter;
 import java.io.StringWriter;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/gxp/src/main/java/org/apache/struts2/views/gxp/AbstractGxpResult.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/gxp/src/main/java/org/apache/struts2/views/gxp/AbstractGxpResult.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/javatemplates/src/main/java/org/apache/struts2/views/java/simple/AbstractTagHandler.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/javatemplates/src/main/java/org/apache/struts2/views/java/simple/AbstractTagHandler.java Wed Nov 30 19:35:34 2011
@@ -20,8 +20,8 @@
  */
 package org.apache.struts2.views.java.simple;
 
-import com.opensymphony.xwork2.util.TextParseUtil;
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.TextParseUtil;
+import org.apache.struts2.xwork2.util.ValueStack;
 import org.apache.struts2.components.template.TemplateRenderingContext;
 import org.apache.struts2.components.Component;
 import org.apache.struts2.views.java.Attributes;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/javatemplates/src/test/java/org/apache/struts2/views/java/simple/AbstractTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/javatemplates/src/test/java/org/apache/struts2/views/java/simple/AbstractTest.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/javatemplates/src/test/java/org/apache/struts2/views/java/simple/AbstractTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/javatemplates/src/test/java/org/apache/struts2/views/java/simple/AbstractTest.java Wed Nov 30 19:35:34 2011
@@ -21,10 +21,10 @@
 
 package org.apache.struts2.views.java.simple;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.conversion.impl.XWorkConverter;
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.conversion.impl.XWorkConverter;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.util.ValueStack;
 import junit.framework.TestCase;
 import org.apache.struts2.StrutsConstants;
 import org.apache.struts2.ServletActionContext;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/ActionFormResetInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/ActionFormResetInterceptor.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/ActionFormResetInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/ActionFormResetInterceptor.java Wed Nov 30 19:35:34 2011
@@ -26,13 +26,12 @@ import javax.servlet.http.HttpServletReq
 import org.apache.struts.action.ActionForm;
 import org.apache.struts.action.ActionMapping;
 import org.apache.struts2.ServletActionContext;
-import org.apache.struts2.dispatcher.Dispatcher;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.config.Configuration;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.interceptor.AbstractInterceptor;
-import com.opensymphony.xwork2.interceptor.ScopedModelDriven;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.config.Configuration;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.interceptor.AbstractInterceptor;
+import org.apache.struts2.xwork2.interceptor.ScopedModelDriven;
 
 /**
  *  Calls the reset() method on the ActionForm, if it exists.

Modified: struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/ActionFormValidationInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/ActionFormValidationInterceptor.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/ActionFormValidationInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/ActionFormValidationInterceptor.java Wed Nov 30 19:35:34 2011
@@ -43,15 +43,15 @@ import org.apache.struts2.ServletActionC
 import org.apache.struts2.StrutsException;
 import org.xml.sax.SAXException;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.TextProvider;
-import com.opensymphony.xwork2.config.Configuration;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.interceptor.AbstractInterceptor;
-import com.opensymphony.xwork2.interceptor.ScopedModelDriven;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.TextProvider;
+import org.apache.struts2.xwork2.config.Configuration;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.interceptor.AbstractInterceptor;
+import org.apache.struts2.xwork2.interceptor.ScopedModelDriven;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  *  Calls the validate() method on the ActionForm, if it exists.  The errors are handled

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/Action.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/Action.java?rev=1208724&r1=1207009&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/Action.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/Action.java Wed Nov 30 19:35:34 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2;
+package org.apache.struts2.xwork2;
 
 /**
  * All actions <b>may</b> implement this interface, which exposes the <code>execute()</code> method.

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionChainResult.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionChainResult.java?rev=1208724&r1=1207009&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionChainResult.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionChainResult.java Wed Nov 30 19:35:34 2011
@@ -13,13 +13,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2;
+package org.apache.struts2.xwork2;
 
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.TextParseUtil;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.TextParseUtil;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 import java.util.*;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionContext.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionContext.java?rev=1208724&r1=1207009&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionEventListener.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionEventListener.java Wed Nov 30 19:35:34 2011
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2;
+package org.apache.struts2.xwork2;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * Provides hooks for handling key action events

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionInvocation.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionInvocation.java?rev=1208724&r1=1207009&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionInvocation.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionInvocation.java Wed Nov 30 19:35:34 2011
@@ -13,10 +13,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2;
+package org.apache.struts2.xwork2;
 
-import com.opensymphony.xwork2.interceptor.PreResultListener;
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.interceptor.PreResultListener;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 import java.io.Serializable;
 
@@ -27,7 +27,7 @@ import java.io.Serializable;
  * Interceptors are all executed, and then the {@link Action} and the {@link Result}.
  *
  * @author Jason Carreira
- * @see com.opensymphony.xwork2.ActionProxy
+ * @see org.apache.struts2.xwork2.ActionProxy
  */
 public interface ActionInvocation extends Serializable {
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionProxy.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionProxy.java?rev=1208724&r1=1207009&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionProxy.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionProxy.java Wed Nov 30 19:35:34 2011
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2;
+package org.apache.struts2.xwork2;
 
-import com.opensymphony.xwork2.config.entities.ActionConfig;
+import org.apache.struts2.xwork2.config.entities.ActionConfig;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionProxyFactory.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionProxyFactory.java?rev=1208724&r1=1207009&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionProxyFactory.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionProxyFactory.java Wed Nov 30 19:35:34 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2;
+package org.apache.struts2.xwork2;
 
 import java.util.Map;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/config/entities/ActionConfig.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/config/entities/ActionConfig.java?rev=1208724&r1=1207009&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/config/entities/ActionConfig.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/config/entities/ActionConfig.java Wed Nov 30 19:35:34 2011
@@ -13,10 +13,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.config.entities;
+package org.apache.struts2.xwork2.config.entities;
 
-import com.opensymphony.xwork2.util.location.Located;
-import com.opensymphony.xwork2.util.location.Location;
+import org.apache.struts2.xwork2.util.location.Located;
+import org.apache.struts2.xwork2.util.location.Location;
 
 import java.io.Serializable;
 import java.util.*;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/config/impl/AbstractMatcher.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/config/impl/AbstractMatcher.java?rev=1208724&r1=1207009&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/config/impl/AbstractMatcher.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/config/impl/AbstractMatcher.java Wed Nov 30 19:35:34 2011
@@ -15,11 +15,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.config.impl;
+package org.apache.struts2.xwork2.config.impl;
 
-import com.opensymphony.xwork2.util.PatternMatcher;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.PatternMatcher;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 import java.io.Serializable;
 import java.util.*;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/config/impl/ActionConfigMatcher.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/config/impl/ActionConfigMatcher.java?rev=1208724&r1=1207009&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/config/impl/ActionConfigMatcher.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/config/impl/ActionConfigMatcher.java Wed Nov 30 19:35:34 2011
@@ -15,13 +15,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.config.impl;
+package org.apache.struts2.xwork2.config.impl;
 
-import com.opensymphony.xwork2.config.entities.ActionConfig;
-import com.opensymphony.xwork2.config.entities.ExceptionMappingConfig;
-import com.opensymphony.xwork2.config.entities.ResultConfig;
-import com.opensymphony.xwork2.util.PatternMatcher;
-import com.opensymphony.xwork2.util.WildcardHelper;
+import org.apache.struts2.xwork2.config.entities.ActionConfig;
+import org.apache.struts2.xwork2.config.entities.ExceptionMappingConfig;
+import org.apache.struts2.xwork2.config.entities.ResultConfig;
+import org.apache.struts2.xwork2.util.PatternMatcher;
+import org.apache.struts2.xwork2.util.WildcardHelper;
 
 import java.io.Serializable;
 import java.util.ArrayList;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/interceptor/AbstractInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/interceptor/AbstractInterceptor.java?rev=1208724&r1=1207009&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/interceptor/AbstractInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/interceptor/AbstractInterceptor.java Wed Nov 30 19:35:34 2011
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.interceptor;
+package org.apache.struts2.xwork2.interceptor;
 
-import com.opensymphony.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.ActionInvocation;
 
 /**
  * Provides default implementations of optional lifecycle methods

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/spring/interceptor/ActionAutowiringInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/spring/interceptor/ActionAutowiringInterceptor.java?rev=1208724&r1=1207009&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/spring/interceptor/ActionAutowiringInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/spring/interceptor/ActionAutowiringInterceptor.java Wed Nov 30 19:35:34 2011
@@ -14,14 +14,14 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.spring.interceptor;
+package org.apache.struts2.xwork2.spring.interceptor;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.interceptor.AbstractInterceptor;
-import com.opensymphony.xwork2.spring.SpringObjectFactory;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.interceptor.AbstractInterceptor;
+import org.apache.struts2.xwork2.spring.SpringObjectFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.springframework.beans.BeansException;
 import org.springframework.context.ApplicationContext;
 import org.springframework.context.ApplicationContextAware;
@@ -62,7 +62,7 @@ import org.springframework.web.context.W
 public class ActionAutowiringInterceptor extends AbstractInterceptor implements ApplicationContextAware {
     private static final Logger LOG = LoggerFactory.getLogger(ActionAutowiringInterceptor.class);
 
-    public static final String APPLICATION_CONTEXT = "com.opensymphony.xwork2.spring.interceptor.ActionAutowiringInterceptor.applicationContext";
+    public static final String APPLICATION_CONTEXT = "org.apache.struts2.xwork2.spring.interceptor.ActionAutowiringInterceptor.applicationContext";
 
     private boolean initialized = false;
     private ApplicationContext context;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/validator/metadata/AbstractFieldValidatorDescription.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/validator/metadata/AbstractFieldValidatorDescription.java?rev=1208724&r1=1207009&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/validator/metadata/AbstractFieldValidatorDescription.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/validator/metadata/AbstractFieldValidatorDescription.java Wed Nov 30 19:35:34 2011
@@ -13,10 +13,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator.metadata;
+package org.apache.struts2.xwork2.validator.metadata;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * <code>AbstractFieldValidatorDescription</code>

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/validator/validators/AbstractRangeValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/validator/validators/AbstractRangeValidator.java?rev=1208724&r1=1207009&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/validator/validators/AbstractRangeValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/validator/validators/AbstractRangeValidator.java Wed Nov 30 19:35:34 2011
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator.validators;
+package org.apache.struts2.xwork2.validator.validators;
 
-import com.opensymphony.xwork2.validator.ValidationException;
+import org.apache.struts2.xwork2.validator.ValidationException;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/ActionContextTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/ActionContextTest.java?rev=1208724&r1=1207009&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/ActionContextTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/ActionContextTest.java Wed Nov 30 19:35:34 2011
@@ -13,10 +13,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2;
+package org.apache.struts2.xwork2;
 
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.ValueStackFactory;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStackFactory;
 
 import java.util.HashMap;
 import java.util.Map;
@@ -29,10 +29,10 @@ import java.util.Map;
  */
 public class ActionContextTest extends XWorkTestCase {
 
-    private static final String APPLICATION_KEY = "com.opensymphony.xwork2.ActionContextTest.application";
-    private static final String SESSION_KEY = "com.opensymphony.xwork2.ActionContextTest.session";
-    private static final String PARAMETERS_KEY = "com.opensymphony.xwork2.ActionContextTest.params";
-    private static final String ACTION_NAME = "com.opensymphony.xwork2.ActionContextTest.actionName";
+    private static final String APPLICATION_KEY = "org.apache.struts2.xwork2.ActionContextTest.application";
+    private static final String SESSION_KEY = "org.apache.struts2.xwork2.ActionContextTest.session";
+    private static final String PARAMETERS_KEY = "org.apache.struts2.xwork2.ActionContextTest.params";
+    private static final String ACTION_NAME = "org.apache.struts2.xwork2.ActionContextTest.actionName";
 
     private ActionContext context;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/ActionContextThreadLocalTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/ActionContextThreadLocalTest.java?rev=1208724&r1=1207009&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/ActionContextThreadLocalTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/ActionContextThreadLocalTest.java Wed Nov 30 19:35:34 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2;
+package org.apache.struts2.xwork2;
 
 import junit.framework.TestCase;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/ActionInvocationTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/ActionInvocationTest.java?rev=1208724&r1=1207009&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/ActionInvocationTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/ActionInvocationTest.java Wed Nov 30 19:35:34 2011
@@ -13,10 +13,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2;
+package org.apache.struts2.xwork2;
 
-import com.opensymphony.xwork2.config.entities.ActionConfig;
-import com.opensymphony.xwork2.config.providers.XmlConfigurationProvider;
+import org.apache.struts2.xwork2.config.entities.ActionConfig;
+import org.apache.struts2.xwork2.config.providers.XmlConfigurationProvider;
 
 import java.util.HashMap;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/ActionNestingTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/ActionNestingTest.java?rev=1208724&r1=1207009&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/ActionNestingTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/ActionNestingTest.java Wed Nov 30 19:35:34 2011
@@ -13,17 +13,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2;
+package org.apache.struts2.xwork2;
 
-import com.opensymphony.xwork2.config.Configuration;
-import com.opensymphony.xwork2.config.ConfigurationProvider;
-import com.opensymphony.xwork2.config.entities.ActionConfig;
-import com.opensymphony.xwork2.config.entities.PackageConfig;
-import com.opensymphony.xwork2.config.entities.ResultConfig;
-import com.opensymphony.xwork2.inject.ContainerBuilder;
-import com.opensymphony.xwork2.mock.MockResult;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.location.LocatableProperties;
+import org.apache.struts2.xwork2.config.Configuration;
+import org.apache.struts2.xwork2.config.ConfigurationProvider;
+import org.apache.struts2.xwork2.config.entities.ActionConfig;
+import org.apache.struts2.xwork2.config.entities.PackageConfig;
+import org.apache.struts2.xwork2.config.entities.ResultConfig;
+import org.apache.struts2.xwork2.inject.ContainerBuilder;
+import org.apache.struts2.xwork2.mock.MockResult;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.location.LocatableProperties;
 
 import java.util.HashMap;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/config/entities/ActionConfigTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/config/entities/ActionConfigTest.java?rev=1208724&r1=1207009&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/config/entities/ActionConfigTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/config/entities/ActionConfigTest.java Wed Nov 30 19:35:34 2011
@@ -13,10 +13,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.config.entities;
+package org.apache.struts2.xwork2.config.entities;
 
-import com.opensymphony.xwork2.XWorkTestCase;
-import com.opensymphony.xwork2.util.location.LocationImpl;
+import org.apache.struts2.xwork2.XWorkTestCase;
+import org.apache.struts2.xwork2.util.location.LocationImpl;
 
 /**
  * ActionConfigTest

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/config/impl/ActionConfigMatcherTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/config/impl/ActionConfigMatcherTest.java?rev=1208724&r1=1207009&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/config/impl/ActionConfigMatcherTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/config/impl/ActionConfigMatcherTest.java Wed Nov 30 19:35:34 2011
@@ -15,13 +15,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.config.impl;
+package org.apache.struts2.xwork2.config.impl;
 
-import com.opensymphony.xwork2.XWorkTestCase;
-import com.opensymphony.xwork2.config.entities.ActionConfig;
-import com.opensymphony.xwork2.config.entities.ExceptionMappingConfig;
-import com.opensymphony.xwork2.config.entities.InterceptorMapping;
-import com.opensymphony.xwork2.config.entities.ResultConfig;
+import org.apache.struts2.xwork2.XWorkTestCase;
+import org.apache.struts2.xwork2.config.entities.ActionConfig;
+import org.apache.struts2.xwork2.config.entities.ExceptionMappingConfig;
+import org.apache.struts2.xwork2.config.entities.InterceptorMapping;
+import org.apache.struts2.xwork2.config.entities.ResultConfig;
 
 import java.util.HashMap;
 import java.util.Map;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/spring/ActionsFromSpringTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/spring/ActionsFromSpringTest.java?rev=1208724&r1=1207009&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/spring/ActionsFromSpringTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/spring/ActionsFromSpringTest.java Wed Nov 30 19:35:34 2011
@@ -1,10 +1,10 @@
 /*
  * Created on Jun 12, 2004
  */
-package com.opensymphony.xwork2.spring;
+package org.apache.struts2.xwork2.spring;
 
-import com.opensymphony.xwork2.*;
-import com.opensymphony.xwork2.config.providers.XmlConfigurationProvider;
+import org.apache.struts2.xwork2.*;
+import org.apache.struts2.xwork2.config.providers.XmlConfigurationProvider;
 import org.springframework.context.ApplicationContext;
 
 /**
@@ -19,7 +19,7 @@ public class ActionsFromSpringTest exten
         super.setUp();
 
         // Set up XWork
-        loadConfigurationProviders(new XmlConfigurationProvider("com/opensymphony/xwork2/spring/actionContext-xwork.xml"));
+        loadConfigurationProviders(new XmlConfigurationProvider("org/apache/struts2/xwork2/spring/actionContext-xwork.xml"));
         appContext = ((SpringObjectFactory)container.getInstance(ObjectFactory.class)).appContext;
     }
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/spring/interceptor/ActionAutowiringInterceptorTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/spring/interceptor/ActionAutowiringInterceptorTest.java?rev=1208724&r1=1207009&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/spring/interceptor/ActionAutowiringInterceptorTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/test/java/org/apache/struts2/xwork2/spring/interceptor/ActionAutowiringInterceptorTest.java Wed Nov 30 19:35:34 2011
@@ -1,10 +1,10 @@
 /*
  * Created on 6/11/2004
  */
-package com.opensymphony.xwork2.spring.interceptor;
+package org.apache.struts2.xwork2.spring.interceptor;
 
-import com.opensymphony.xwork2.*;
-import com.opensymphony.xwork2.config.providers.XmlConfigurationProvider;
+import org.apache.struts2.xwork2.*;
+import org.apache.struts2.xwork2.config.providers.XmlConfigurationProvider;
 import org.springframework.context.ApplicationContext;
 import org.springframework.web.context.WebApplicationContext;
 import org.springframework.web.context.support.StaticWebApplicationContext;
@@ -39,7 +39,7 @@ public class ActionAutowiringInterceptor
     public void testSetAutowireType() throws Exception {
         XmlConfigurationProvider prov = new XmlConfigurationProvider("xwork-default.xml");
         prov.setThrowExceptionOnDuplicateBeans(false);
-        XmlConfigurationProvider c = new XmlConfigurationProvider("com/opensymphony/xwork2/spring/xwork-autowire.xml");
+        XmlConfigurationProvider c = new XmlConfigurationProvider("org/apache/struts2/xwork2/spring/xwork-autowire.xml");
         loadConfigurationProviders(c, prov);
 
         StaticWebApplicationContext appContext = new StaticWebApplicationContext();
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/ActionMappingParametersInteceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/ActionMappingParametersInteceptor.java Wed Nov 30 19:35:34 2011
@@ -21,8 +21,8 @@
 
 package org.apache.struts2.interceptor;
 
-import com.opensymphony.xwork2.interceptor.ParametersInterceptor;
-import com.opensymphony.xwork2.ActionContext;
+import org.apache.struts2.xwork2.interceptor.ParametersInterceptor;
+import org.apache.struts2.xwork2.ActionContext;
 
 import java.util.Map;
 import java.util.Collections;
@@ -54,7 +54,7 @@ import org.apache.struts2.dispatcher.map
  * <p/>
  * <!-- START SNIPPET: extending -->
  * <p/>
  * <p/> The best way to add behavior to this interceptor is to utilize the {@link com.opensymphony.xwork2.interceptor.ParameterNameAware} interface in your
  * actions. However, if you wish to apply a global rule that isn't implemented in your action, then you could extend
  * this interceptor and override the {@link #acceptableName(String)} method.
  * <p/>
@@ -54,7 +54,7 @@ import org.apache.struts2.dispatcher.map
  * <!-- START SNIPPET: extending -->
  * <p/>
- * <p/> The best way to add behavior to this interceptor is to utilize the {@link com.opensymphony.xwork2.interceptor.ParameterNameAware} interface in your
+ * <p/> The best way to add behavior to this interceptor is to utilize the {@link org.apache.struts2.xwork2.interceptor.ParameterNameAware} interface in your
  * actions. However, if you wish to apply a global rule that isn't implemented in your action, then you could extend
  * this interceptor and override the {@link #acceptableName(String)} method.

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ActionErrorModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ActionErrorModel.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/gxp/src/main/java/org/apache/struts2/views/gxp/AbstractGxpResult.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/gxp/src/main/java/org/apache/struts2/views/gxp/AbstractGxpResult.java Wed Nov 30 19:35:34 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.views.gxp;
 
-import com.opensymphony.xwork2.Result;
+import org.apache.struts2.xwork2.Result;
 import org.apache.struts2.ServletActionContext;
 
 import javax.servlet.http.HttpServletResponse;
@@ -52,7 +52,7 @@ import java.util.Locale;
  *     &lt;/result-types>
  * </pre>
  * This means that Struts 2 will attempt to instantiate the {@code Interface}
  * using the {@link com.opensymphony.xwork2.ObjectFactory}. If
  * {@link com.google.webwork.GuiceWebWorkIntegrationModule} is installed, or
  * {@link com.google.webwork.ContainerObjectFactory} is set as the static
  * {@code ObjectFactory} instance, then Guice will be used to instantiate the
@@ -52,7 +52,7 @@ import java.util.Locale;
  * </pre>
  * This means that Struts 2 will attempt to instantiate the {@code Interface}
- * using the {@link com.opensymphony.xwork2.ObjectFactory}. If
+ * using the {@link org.apache.struts2.xwork2.ObjectFactory}. If
  * {@link com.google.webwork.GuiceWebWorkIntegrationModule} is installed, or
  * {@link com.google.webwork.ContainerObjectFactory} is set as the static

Modified: struts/struts2/branches/STRUTS_3_X/plugins/javatemplates/src/main/java/org/apache/struts2/views/java/simple/AbstractTagHandler.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/javatemplates/src/main/java/org/apache/struts2/views/java/simple/AbstractTagHandler.java?rev=1208724&r1=1208723&r2=1208724&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionContext.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionContext.java Wed Nov 30 19:35:34 2011
@@ -13,10 +13,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2;
+package org.apache.struts2.xwork2;
 
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 import java.io.Serializable;
 import java.util.HashMap;
@@ -52,53 +52,53 @@ public class ActionContext implements Se
     /**
      * Constant for the name of the action being executed.
      */
-    public static final String ACTION_NAME = "com.opensymphony.xwork2.ActionContext.name";
+    public static final String ACTION_NAME = "org.apache.struts2.xwork2.ActionContext.name";
 
     /**
      * Constant for the {@link com.opensymphony.xwork2.util.ValueStack OGNL value stack}.
      */
     public static final String VALUE_STACK = ValueStack.VALUE_STACK;
 
     /**
      * Constant for the action's session.
      */
-    public static final String SESSION = "com.opensymphony.xwork2.ActionContext.session";
+    public static final String SESSION = "org.apache.struts2.xwork2.ActionContext.session";
 
     /**
      * Constant for the action's application context.
      */
-    public static final String APPLICATION = "com.opensymphony.xwork2.ActionContext.application";
+    public static final String APPLICATION = "org.apache.struts2.xwork2.ActionContext.application";
 
     /**
      * Constant for the action's parameters.
      */
-    public static final String PARAMETERS = "com.opensymphony.xwork2.ActionContext.parameters";
+    public static final String PARAMETERS = "org.apache.struts2.xwork2.ActionContext.parameters";
 
     /**
      * Constant for the action's locale.
      */
-    public static final String LOCALE = "com.opensymphony.xwork2.ActionContext.locale";
+    public static final String LOCALE = "org.apache.struts2.xwork2.ActionContext.locale";
 
     /**
      * Constant for the action's type converter.
      */
-    public static final String TYPE_CONVERTER = "com.opensymphony.xwork2.ActionContext.typeConverter";
+    public static final String TYPE_CONVERTER = "org.apache.struts2.xwork2.ActionContext.typeConverter";
 
     /**
      * Constant for the action's {@link com.opensymphony.xwork2.ActionInvocation invocation} context.
      */
-    public static final String ACTION_INVOCATION = "com.opensymphony.xwork2.ActionContext.actionInvocation";
+    public static final String ACTION_INVOCATION = "org.apache.struts2.xwork2.ActionContext.actionInvocation";
 
     /**
      * Constant for the map of type conversion errors.
      */
-    public static final String CONVERSION_ERRORS = "com.opensymphony.xwork2.ActionContext.conversionErrors";
+    public static final String CONVERSION_ERRORS = "org.apache.struts2.xwork2.ActionContext.conversionErrors";
 
 
     /**
      * Constant for the container
      */
-    public static final String CONTAINER = "com.opensymphony.xwork2.ActionContext.container";
+    public static final String CONTAINER = "org.apache.struts2.xwork2.ActionContext.container";
     
     Map<String, Object> context;
 
@@ -52,53 +52,53 @@ public class ActionContext implements Se
 
     /**
-     * Constant for the {@link com.opensymphony.xwork2.util.ValueStack OGNL value stack}.
+     * Constant for the {@link org.apache.struts2.xwork2.util.ValueStack OGNL value stack}.
      */
     public static final String VALUE_STACK = ValueStack.VALUE_STACK;
@@ -52,53 +52,53 @@ public class ActionContext implements Se
 
     /**
-     * Constant for the action's {@link com.opensymphony.xwork2.ActionInvocation invocation} context.
+     * Constant for the action's {@link org.apache.struts2.xwork2.ActionInvocation invocation} context.
      */

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionEventListener.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/org/apache/struts2/xwork2/ActionEventListener.java?rev=1208724&r1=1207009&r2=1208724&view=diff
==============================================================================